==> rosegarden-trinity_3.5.13.2.orig.tar.xz: rosegarden-trinity-3.5.13.2/src/gui/seqmanager/SpecialSegmentMmapper.cpp <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
 
    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>
 
    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.
 
    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/


#include "SpecialSegmentMmapper.h"

#include <kstddirs.h>
#include "base/Event.h"
#include "base/Segment.h"
#include "base/TriggerSegment.h"
#include "document/RosegardenGUIDoc.h"
#include "SegmentMmapper.h"
#include <kglobal.h>
#include <tqstring.h>


namespace Rosegarden
{

SpecialSegmentMmapper::SpecialSegmentMmapper(RosegardenGUIDoc* doc,
        TQString baseFileName)
        : SegmentMmapper(doc, 0, createFileName(baseFileName))
{}

TQString SpecialSegmentMmapper::createFileName(TQString baseFileName)
{
    return KGlobal::dirs()->resourceDirs("tmp").last() + "/" + baseFileName;
}

unsigned int SpecialSegmentMmapper::getSegmentRepeatCount()
{
    return 1;
}

}

==> rosegarden-trinity-14.0.6.tar.xz: rosegarden-trinity-14.0.6/src/gui/seqmanager/SpecialSegmentMmapper.cpp <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
 
    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>
 
    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.
 
    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/


#include "SpecialSegmentMmapper.h"

#include <kstddirs.h>
#include "base/Event.h"
#include "base/Segment.h"
#include "base/TriggerSegment.h"
#include "document/RosegardenGUIDoc.h"
#include "SegmentMmapper.h"
#include <tdeglobal.h>
#include <tqstring.h>


namespace Rosegarden
{

SpecialSegmentMmapper::SpecialSegmentMmapper(RosegardenGUIDoc* doc,
        TQString baseFileName)
        : SegmentMmapper(doc, 0, createFileName(baseFileName))
{}

TQString SpecialSegmentMmapper::createFileName(TQString baseFileName)
{
    return TDEGlobal::dirs()->resourceDirs("tmp").last() + "/" + baseFileName;
}

unsigned int SpecialSegmentMmapper::getSegmentRepeatCount()
{
    return 1;
}

}
